==> ReleaseV1.1.0.tar.gz: winginterfacelibrary/src/Interface/IOrganizationService.cs <==
﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.User;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.Request.Organization;
using WingInterfaceLibrary.Result.Organization;
using WingInterfaceLibrary.Result.Languge;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Languge;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 机构信息服务接口
    /// </summary>
    /// <value>机构信息模块</value>
    /// <example>客户端API</example>
    [System.ComponentModel.Description("WingUserModule")]
    public interface IOrganizationService
    {
        /// <summary>
        /// 搜索组织
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>组织信息列表</returns>
        Task<List<OrganizationDTO>> SearchOrganizationsAsync(SearchOrganizationsRequest request);

        /// <summary>
        /// 根据编号获取机构信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>组织信息列表</returns>
        Task<OrganizationDTO> GetOrganizationByCodeAsync(GetOrganizationByCodeRequest request);

        /// <summary>
        /// 查询上级机构列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>上级机构列表</returns>
        Task<List<OrganizationBaseDTO>> GetParentOrganizationListAsync(GetParentOrganizationListRequest request);

        /// <summary>
        /// 查询可转诊机构列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>机构列表</returns>
        Task<PageResult<OrganizationBaseDTO>> FindOrganizationsByPageAsync(FindOrganizationListRequest request);

        /// <summary>
        /// 分页查询上级机构列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>机构列表</returns>
        Task<PageResult<OrganizationBaseDTO>> FindPatientOrganizationsByPageAsync(FindPatientOrganizationsByPageRequest request);

        /// <summary>
        /// 查询机构详细信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>机构详细信息</returns>
        Task<OrganizationBasicDTO> GetPersonOrganizationAsync(GetPersonOrganizationRequest request);

        /// <summary>
        /// 保存机构信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>OrganizationCodeIsEmpty,OrganizationNameIsEmpty,UserOrganizationCodeEmpty</errorCodes>
        Task<bool> SavePersonOrganizationAsync(SavePersonOrganizationRequest request);

        /// <summary>
        /// 添加组织
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>OrganizationNameIsEmpty,NameLengthError,PatientTypeError,OrganizationNameDuplicate</errorCodes>
        Task<bool> AddOrganizationsAsync(AddOrganizationsRequest request);

        /// <summary>
        /// 删除组织
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> RemoveOrganizationsAsync(RemoveOrganizationsRequest request);

        /// <summary>
        /// 修改机构名称
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>OrganizationCodeIsEmpty,OrganizationNameIsEmpty,OrganizationNameDuplicate</errorCodes>
        Task<bool> UpdateOrganizationNameAsync(UpdateOrganizationNameRequest request);

        /// <summary>
        /// 获取机构配置信息（病人、检查）
        /// </summary>
        /// <param name="request">获取配置信息请求实体</param>
        /// <returns></returns>
        /// <errorCodes>UserNotExisted,UserVersionInValid,UserGreaterThanNewestVersion,UserGreaterThanNewestVersion</errorCodes>
        Task<OrganizationSettingResult> GetOrganizationSettingAsync(GetUserOrganizationSettingRequest request);

        /// <summary>
        /// 客户端获取Server配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>UserNotExisted</errorCodes>
        Task<ServerSettingResult> GetServerSettingAsync(TokenRequest request);

        /// <summary>
        /// 获取语言配置列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>UserNotExisted</errorCodes>
        Task<List<LangugeDataResult>> GetLangugeDataListAsync(LangugeDataRequest request);

    }
}

==> ReleaseV1.1.3.tar.gz: winginterfacelibrary/src/Interface/IOrganizationService.cs <==
﻿using System.Threading.Tasks;
using System.Collections.Generic;
using WingInterfaceLibrary.Request.User;
using WingInterfaceLibrary.DTO.Organization;
using WingInterfaceLibrary.Request.Organization;
using WingInterfaceLibrary.Result.Organization;
using WingInterfaceLibrary.Result.Languge;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Languge;
using WingInterfaceLibrary.Result;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 机构信息服务接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>机构信息模块</docSecondDirectory>
    public interface IOrganizationService
    {
        /// <summary>
        /// 搜索组织
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>组织信息列表</returns>
        Task<List<OrganizationDTO>> SearchOrganizationsAsync(SearchOrganizationsRequest request);

        /// <summary>
        /// 根据编号获取机构信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>组织信息列表</returns>
        Task<OrganizationDTO> GetOrganizationByCodeAsync(GetOrganizationByCodeRequest request);

        /// <summary>
        /// 查询上级机构列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>上级机构列表</returns>
        Task<List<OrganizationBaseDTO>> GetParentOrganizationListAsync(GetParentOrganizationListRequest request);

        /// <summary>
        /// 查询可转诊机构列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>机构列表</returns>
        Task<PageResult<OrganizationBaseDTO>> FindOrganizationsByPageAsync(FindOrganizationListRequest request);

        /// <summary>
        /// 分页查询上级机构列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>机构列表</returns>
        Task<PageResult<OrganizationBaseDTO>> FindPatientOrganizationsByPageAsync(FindPatientOrganizationsByPageRequest request);

        /// <summary>
        /// 查询机构详细信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>机构详细信息</returns>
        Task<OrganizationBasicDTO> GetPersonOrganizationAsync(GetPersonOrganizationRequest request);

        /// <summary>
        /// 保存机构信息
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>OrganizationCodeIsEmpty,OrganizationNameIsEmpty,UserOrganizationCodeEmpty,UserOrgCanNotChoseChild</errorCodes>
        Task<bool> SavePersonOrganizationAsync(SavePersonOrganizationRequest request);

        /// <summary>
        /// 添加组织
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>OrganizationNameIsEmpty,NameLengthError,PatientTypeError,OrganizationNameDuplicate</errorCodes>
        Task<bool> AddOrganizationsAsync(AddOrganizationsRequest request);

        /// <summary>
        /// 删除组织
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> RemoveOrganizationsAsync(RemoveOrganizationsRequest request);

        /// <summary>
        /// 修改机构名称
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>OrganizationCodeIsEmpty,OrganizationNameIsEmpty,OrganizationNameDuplicate</errorCodes>
        Task<bool> UpdateOrganizationNameAsync(UpdateOrganizationNameRequest request);

        /// <summary>
        /// 获取机构配置信息
        /// </summary>
        /// <param name="request">获取配置信息请求实体</param>
        /// <returns></returns>
        /// <errorCodes>UserNotExisted,UserVersionInValid,UserGreaterThanNewestVersion,UserGreaterThanNewestVersion</errorCodes>
        Task<OrganizationSettingResult> GetOrganizationSettingAsync(GetUserOrganizationSettingRequest request);

        /// <summary>
        /// 客户端获取Server配置
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>UserNotExisted</errorCodes>
        Task<ServerSettingResult> GetServerSettingAsync(TokenRequest request);

        /// <summary>
        /// 获取语言配置列表
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>UserNotExisted</errorCodes>
        Task<List<LangugeDataResult>> GetLangugeDataListAsync(LangugeDataRequest request);

    }
}
